/*
 * Copyright 2008 Evan Cowden
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */
package org.nakedosgi.spi;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * <p>Mark a class as a service provider</p>
 * 
 * <p>If no value is specified, a service provider configuration will be
 * created for each directly implemented interface.  Otherwise, a
 * configuration will be generated for the specified type.</p>
 * 
 * @author Evan Cowden
 */
@Documented
@Retention(RetentionPolicy.SOURCE)
@Target(ElementType.TYPE)
public @interface ServiceProvider {

    /**
     * The service interface implemented by the annotated class.  If left
     * unspecified, a configuration will be generated for each interface
     * directly implemented by the annotated class.
     */
    public Class value() default Void.class;
 }
